@@ -1,12 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2021 -- leonerd@leonerd.org.uk
 
-use 5.026; # signatures
-use Object::Pad 0.17;
+use v5.26; # signatures
+use Object::Pad 0.27;
 
-class Tickit::Widget::ScrollBox 0.08
+package Tickit::Widget::ScrollBox 0.10;
+class Tickit::Widget::ScrollBox
    extends Tickit::SingleChildWidget 0.53;
 
 Tickit::Window->VERSION( '0.39' ); # ->scroll_with_children, default expose_after_scroll
@@ -180,13 +181,22 @@ has $_child_is_scrollable;
 
 has $_viewport;
 
-method BUILD ( %args )
+BUILD ( %args )
 {
    my $vertical   = $args{vertical} // 1;
    my $horizontal = $args{horizontal};
 
-   $_vextent = Tickit::Widget::ScrollBox::Extent->new( $self, "v" ) if $vertical;
-   $_hextent = Tickit::Widget::ScrollBox::Extent->new( $self, "h" ) if $horizontal;
+   $vertical and
+      $_vextent = Tickit::Widget::ScrollBox::Extent->new(
+         scrollbox => $self,
+         id        => "v",
+      );
+
+   $horizontal and
+      $_hextent = Tickit::Widget::ScrollBox::Extent->new(
+         scrollbox => $self,
+         id        => "h",
+      );
 
    $_v_on_demand = $vertical  ||'' eq "on_demand";
    $_h_on_demand = $horizontal||'' eq "on_demand";
